@@ -3,8 +3,10 @@ library("vdiffr")
 invisible(vcr::vcr_configure(
   dir = "../cassettes",
   record = "new_episodes",
+  clean_outdated_http_interactions = TRUE,
   filter_sensitive_data = list(
-    "<finbif_token>" = Sys.getenv("FINBIF_ACCESS_TOKEN")
+    "<finbif_token>"     = Sys.getenv("FINBIF_ACCESS_TOKEN"),
+    "<finbif_dev_token>" = Sys.getenv("FINBIF_DEV_ACCESS_TOKEN")
   )
 ))
 
